==> haskell-rawfilepath-1.1.1-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rawfilepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rawfilepath
version:              1.1.1
visibility:           public
id:                   rawfilepath-1.1.1-HCtURbVRO8RIL57Kyg2pkS
key:                  rawfilepath-1.1.1-HCtURbVRO8RIL57Kyg2pkS
license:              Apache-2.0
copyright:            (C) 2016-2024 XT et al.
maintainer:           git@xtendo.org
author:               XT et al.
homepage:             https://github.com/xtendo-org/rawfilepath#readme
synopsis:             Use RawFilePath instead of FilePath
description:
    A fast and safe API with high-level features on `RawFilePath`, instead of `FilePath`, to avoid the encoding issues or performance penalties. Please see `README.md`

category:             System
abi:                  1c7d24ca7f1fd7fe9aabd7f36167cbf3
exposed:              True
exposed-modules:
    Data.ByteString.RawFilePath RawFilePath RawFilePath.Directory
    RawFilePath.Process

hidden-modules:
    RawFilePath.Directory.Internal RawFilePath.Import
    RawFilePath.Process.Basic RawFilePath.Process.Common
    RawFilePath.Process.Internal RawFilePath.Process.Posix
    RawFilePath.Process.Utility Paths_rawfilepath

import-dirs:          /usr/lib/ghc-9.2.8/site-local/rawfilepath-1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rawfilepath-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rawfilepath
hs-libraries:         HSrawfilepath-1.1.1-HCtURbVRO8RIL57Kyg2pkS
depends:              base-4.16.4.0 bytestring-0.11.4.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-rawfilepath/html/rawfilepath.haddock
haddock-html:         /usr/share/doc/haskell-rawfilepath/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rawfilepath-1.1.1-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rawfilepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rawfilepath
version:              1.1.1
visibility:           public
id:                   rawfilepath-1.1.1-2pDOkeyoXnzKMo3Bl3slbY
key:                  rawfilepath-1.1.1-2pDOkeyoXnzKMo3Bl3slbY
license:              Apache-2.0
copyright:            (C) 2016-2024 XT et al.
maintainer:           git@xtendo.org
author:               XT et al.
homepage:             https://github.com/xtendo-org/rawfilepath#readme
synopsis:             Use RawFilePath instead of FilePath
description:
    A fast and safe API with high-level features on `RawFilePath`, instead of `FilePath`, to avoid the encoding issues or performance penalties. Please see `README.md`

category:             System
abi:                  989e388f1fdcaedf79cf0d9a51466c12
exposed:              True
exposed-modules:
    Data.ByteString.RawFilePath RawFilePath RawFilePath.Directory
    RawFilePath.Process

hidden-modules:
    RawFilePath.Directory.Internal RawFilePath.Import
    RawFilePath.Process.Basic RawFilePath.Process.Common
    RawFilePath.Process.Internal RawFilePath.Process.Posix
    RawFilePath.Process.Utility Paths_rawfilepath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/rawfilepath-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rawfilepath-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rawfilepath-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rawfilepath
hs-libraries:         HSrawfilepath-1.1.1-2pDOkeyoXnzKMo3Bl3slbY
depends:              base-4.17.2.1 bytestring-0.11.5.3 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-rawfilepath/html/rawfilepath.haddock
haddock-html:         /usr/share/doc/haskell-rawfilepath/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
